pub async fn batch_delete_catalog_objects(
configuration: &Configuration,
batch_delete_catalog_objects_request: BatchDeleteCatalogObjectsRequest,
) -> Result<BatchDeleteCatalogObjectsResponse, Error<BatchDeleteCatalogObjectsError>>Expand description
Deletes a set of CatalogItems based on the provided list of target IDs and returns a set of successfully deleted IDs in the response. Deletion is a cascading event such that all children of the targeted object are also deleted. For example, deleting a CatalogItem will also delete all of its CatalogItemVariation children. BatchDeleteCatalogObjects succeeds even if only a portion of the targeted IDs can be deleted. The response will only include IDs that were actually deleted. To ensure consistency, only one delete request is processed at a time per seller account. While one (batch or non-batch) delete request is being processed, other (batched and non-batched) delete requests are rejected with the 429 error code.