batch_change_inventory

Function batch_change_inventory 

pub async fn batch_change_inventory(
    configuration: &Configuration,
    batch_change_inventory_request: BatchChangeInventoryRequest,
) -> Result<BatchChangeInventoryResponse, Error<BatchChangeInventoryError>>
Applies adjustments and counts to the provided item quantities. On success: returns the current calculated counts for all objects referenced in the request. On failure: returns a list of related errors.