pub struct AppointmentSegment {
pub duration_minutes: Option<Option<i32>>,
pub service_variation_id: Option<Option<String>>,
pub team_member_id: String,
pub service_variation_version: Option<Option<i64>>,
pub intermission_minutes: Option<i32>,
pub any_team_member: Option<bool>,
pub resource_ids: Option<Vec<String>>,
}Expand description
AppointmentSegment : Defines an appointment segment of a booking.
Fields
duration_minutes: Option<Option<i32>>The time span in minutes of an appointment segment.
service_variation_id: Option<Option<String>>The ID of the CatalogItemVariation object representing the service booked in this segment.
team_member_id: StringThe ID of the TeamMember object representing the team member booked in this segment.
service_variation_version: Option<Option<i64>>The current version of the item variation representing the service booked in this segment.
intermission_minutes: Option<i32>Time between the end of this segment and the beginning of the subsequent segment.
any_team_member: Option<bool>Whether the customer accepts any team member, instead of a specific one, to serve this segment.
resource_ids: Option<Vec<String>>The IDs of the seller-accessible resources used for this appointment segment.
Implementations
Sourceimpl AppointmentSegment
impl AppointmentSegment
Sourcepub fn new(team_member_id: String) -> AppointmentSegment
pub fn new(team_member_id: String) -> AppointmentSegment
Defines an appointment segment of a booking.