pub struct BatchRetrieveInventoryCountsRequest {
pub catalog_object_ids: Option<Option<Vec<String>>>,
pub location_ids: Option<Option<Vec<String>>>,
pub updated_after: Option<Option<String>>,
pub cursor: Option<Option<String>>,
pub states: Option<Option<Vec<InventoryState>>>,
pub limit: Option<Option<i32>>,
}Fields
catalog_object_ids: Option<Option<Vec<String>>>The filter to return results by CatalogObject ID. The filter is applicable only when set. The default is null.
location_ids: Option<Option<Vec<String>>>The filter to return results by Location ID. This filter is applicable only when set. The default is null.
updated_after: Option<Option<String>>The filter to return results with their calculated_at value after the given time as specified in an RFC 3339 timestamp. The default value is the UNIX epoch of (1970-01-01T00:00:00Z).
cursor: Option<Option<String>>A pagination cursor returned by a previous call to this endpoint. Provide this to retrieve the next set of results for the original query. See the Pagination guide for more information.
states: Option<Option<Vec<InventoryState>>>The filter to return results by InventoryState. The filter is only applicable when set. Ignored are untracked states of NONE, SOLD, and UNLINKED_RETURN. The default is null.
limit: Option<Option<i32>>The number of records to return.
Implementations