pub struct BatchRetrieveInventoryCountsResponse {
pub errors: Option<Vec<Error>>,
pub counts: Option<Vec<InventoryCount>>,
pub cursor: Option<String>,
}Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
counts: Option<Vec<InventoryCount>>The current calculated inventory counts for the requested objects and locations.
cursor: Option<String>The pagination cursor to be used in a subsequent request. If unset, this is the final response. See the Pagination guide for more information.
Implementations