pub struct BookingCustomAttributeUpsertRequest {
pub booking_id: String,
pub custom_attribute: Box<CustomAttribute>,
pub idempotency_key: Option<Option<String>>,
}Expand description
BookingCustomAttributeUpsertRequest : Represents an individual upsert request in a BulkUpsertBookingCustomAttributes request. An individual request contains a booking ID, the custom attribute to create or update, and an optional idempotency key.
Fields
booking_id: StringThe ID of the target booking.
custom_attribute: Box<CustomAttribute>idempotency_key: Option<Option<String>>A unique identifier for this individual upsert request, used to ensure idempotency. For more information, see Idempotency.
Implementations
Sourceimpl BookingCustomAttributeUpsertRequest
impl BookingCustomAttributeUpsertRequest
Sourcepub fn new(
booking_id: String,
custom_attribute: CustomAttribute,
) -> BookingCustomAttributeUpsertRequest
pub fn new( booking_id: String, custom_attribute: CustomAttribute, ) -> BookingCustomAttributeUpsertRequest
Represents an individual upsert request in a BulkUpsertBookingCustomAttributes request. An individual request contains a booking ID, the custom attribute to create or update, and an optional idempotency key.