pub struct BookingUpdatedEvent {
pub merchant_id: Option<Option<String>>,
pub type: Option<Option<String>>,
pub event_id: Option<Option<String>>,
pub created_at: Option<String>,
pub data: Option<Box<BookingUpdatedEventData>>,
}Expand description
BookingUpdatedEvent : Published when a booking is updated or cancelled. To receive this event with buyer-level permissions, you must have APPOINTMENTS_READ set for the OAuth scope. To receive this event with seller-level permissions, you must have APPOINTMENTS_ALL_READ and APPOINTMENTS_READ set for the OAuth scope.
Fields
merchant_id: Option<Option<String>>The ID of the target seller associated with the event.
type: Option<Option<String>>The type of this event. The value is \"booking.updated\".
event_id: Option<Option<String>>A unique ID for the event.
created_at: Option<String>The timestamp of when the event was created, in RFC 3339 format.
data: Option<Box<BookingUpdatedEventData>>Implementations
Sourceimpl BookingUpdatedEvent
impl BookingUpdatedEvent
Sourcepub fn new() -> BookingUpdatedEvent
pub fn new() -> BookingUpdatedEvent
Published when a booking is updated or cancelled. To receive this event with buyer-level permissions, you must have APPOINTMENTS_READ set for the OAuth scope. To receive this event with seller-level permissions, you must have APPOINTMENTS_ALL_READ and APPOINTMENTS_READ set for the OAuth scope.