pub struct BulkCreateCustomerData {
pub given_name: Option<Option<String>>,
pub family_name: Option<Option<String>>,
pub company_name: Option<Option<String>>,
pub nickname: Option<Option<String>>,
pub email_address: Option<Option<String>>,
pub address: Option<Box<Address>>,
pub phone_number: Option<Option<String>>,
pub reference_id: Option<Option<String>>,
pub note: Option<Option<String>>,
pub birthday: Option<Option<String>>,
pub tax_ids: Option<Box<CustomerTaxIds>>,
}Expand description
BulkCreateCustomerData : Defines the customer data provided in individual create requests for a BulkCreateCustomers operation.
Fields
given_name: Option<Option<String>>The given name (that is, the first name) associated with the customer profile.
family_name: Option<Option<String>>The family name (that is, the last name) associated with the customer profile.
company_name: Option<Option<String>>A business name associated with the customer profile.
nickname: Option<Option<String>>A nickname for the customer profile.
email_address: Option<Option<String>>The email address associated with the customer profile.
address: Option<Box<Address>>phone_number: Option<Option<String>>The phone number associated with the customer profile. The phone number must be valid and can contain 9–16 digits, with an optional + prefix and country code. For more information, see Customer phone numbers.
reference_id: Option<Option<String>>An optional second ID used to associate the customer profile with an entity in another system.
note: Option<Option<String>>A custom note associated with the customer profile.
birthday: Option<Option<String>>The birthday associated with the customer profile, in YYYY-MM-DD or MM-DD format. For example, specify 1998-09-21 for September 21, 1998, or 09-21 for September 21. Birthdays are returned in YYYY-MM-DD format, where YYYY is the specified birth year or 0000 if a birth year is not specified.
tax_ids: Option<Box<CustomerTaxIds>>Implementations
Sourceimpl BulkCreateCustomerData
impl BulkCreateCustomerData
Sourcepub fn new() -> BulkCreateCustomerData
pub fn new() -> BulkCreateCustomerData
Defines the customer data provided in individual create requests for a BulkCreateCustomers operation.