pub struct BulkDeleteOrderCustomAttributesResponse {
pub errors: Option<Vec<Error>>,
pub values: HashMap<String, DeleteOrderCustomAttributeResponse>,
}Expand description
BulkDeleteOrderCustomAttributesResponse : Represents a response from deleting one or more order custom attributes.
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
values: HashMap<String, DeleteOrderCustomAttributeResponse>A map of responses that correspond to individual delete requests. Each response has the same ID as the corresponding request and contains either a custom_attribute or an errors field.
Implementations
Sourceimpl BulkDeleteOrderCustomAttributesResponse
impl BulkDeleteOrderCustomAttributesResponse
Sourcepub fn new(
values: HashMap<String, DeleteOrderCustomAttributeResponse>,
) -> BulkDeleteOrderCustomAttributesResponse
pub fn new( values: HashMap<String, DeleteOrderCustomAttributeResponse>, ) -> BulkDeleteOrderCustomAttributesResponse
Represents a response from deleting one or more order custom attributes.