pub struct BulkUpdateCustomersRequest {
pub customers: HashMap<String, BulkUpdateCustomerData>,
}Expand description
BulkUpdateCustomersRequest : Defines the body parameters that can be included in requests to the BulkUpdateCustomers endpoint.
Fields
customers: HashMap<String, BulkUpdateCustomerData>A map of 1 to 100 individual update requests, represented by customer ID: { customer data } key-value pairs. Each key is the ID of the customer profile to update. To update a customer profile that was created by merging existing profiles, provide the ID of the newly created profile. Each value contains the updated customer data. Only new or changed fields are required. To add or update a field, specify the new value. To remove a field, specify null.
Implementations
Sourceimpl BulkUpdateCustomersRequest
impl BulkUpdateCustomersRequest
Sourcepub fn new(
customers: HashMap<String, BulkUpdateCustomerData>,
) -> BulkUpdateCustomersRequest
pub fn new( customers: HashMap<String, BulkUpdateCustomerData>, ) -> BulkUpdateCustomersRequest
Defines the body parameters that can be included in requests to the BulkUpdateCustomers endpoint.