pub struct CancelSubscriptionResponse {
pub errors: Option<Vec<Error>>,
pub subscription: Option<Box<Subscription>>,
pub actions: Option<Vec<SubscriptionAction>>,
}Expand description
CancelSubscriptionResponse : Defines output parameters in a response from the CancelSubscription endpoint.
Fields
errors: Option<Vec<Error>>Errors encountered during the request.
subscription: Option<Box<Subscription>>actions: Option<Vec<SubscriptionAction>>A list of a single CANCEL action scheduled for the subscription.
Implementations
Sourceimpl CancelSubscriptionResponse
impl CancelSubscriptionResponse
Sourcepub fn new() -> CancelSubscriptionResponse
pub fn new() -> CancelSubscriptionResponse
Defines output parameters in a response from the CancelSubscription endpoint.