pub struct CardUpdatedEvent {
pub merchant_id: Option<Option<String>>,
pub type: Option<Option<String>>,
pub event_id: Option<Option<String>>,
pub created_at: Option<String>,
pub data: Option<Box<CardUpdatedEventData>>,
}Expand description
CardUpdatedEvent : Published when a card is updated by the seller in the Square Dashboard.
Fields
merchant_id: Option<Option<String>>The ID of the target seller associated with the event.
type: Option<Option<String>>The type of this event. The value is \"card.updated\".
event_id: Option<Option<String>>A unique ID for the event.
created_at: Option<String>The timestamp of when the event was created, in RFC 3339 format.
data: Option<Box<CardUpdatedEventData>>Implementations
Sourceimpl CardUpdatedEvent
impl CardUpdatedEvent
Sourcepub fn new() -> CardUpdatedEvent
pub fn new() -> CardUpdatedEvent
Published when a card is updated by the seller in the Square Dashboard.