pub struct CatalogCustomAttributeValue {
pub name: Option<Option<String>>,
pub string_value: Option<Option<String>>,
pub custom_attribute_definition_id: Option<String>,
pub type: Option<CatalogCustomAttributeDefinitionType>,
pub number_value: Option<Option<String>>,
pub boolean_value: Option<Option<bool>>,
pub selection_uid_values: Option<Option<Vec<String>>>,
pub key: Option<String>,
}Expand description
CatalogCustomAttributeValue : An instance of a custom attribute. Custom attributes can be defined and added to ITEM and ITEM_VARIATION type catalog objects. Read more about custom attributes.
Fields
name: Option<Option<String>>The name of the custom attribute.
string_value: Option<Option<String>>The string value of the custom attribute. Populated if type = STRING.
custom_attribute_definition_id: Option<String>The id of the CatalogCustomAttributeDefinition this value belongs to.
type: Option<CatalogCustomAttributeDefinitionType>number_value: Option<Option<String>>Populated if type = NUMBER. Contains a string representation of a decimal number, using a . as the decimal separator.
boolean_value: Option<Option<bool>>A true or false value. Populated if type = BOOLEAN.
selection_uid_values: Option<Option<Vec<String>>>One or more choices from allowed_selections. Populated if type = SELECTION.
key: Option<String>If the associated CatalogCustomAttributeDefinition object is defined by another application, this key is prefixed by the defining application ID. For example, if the CatalogCustomAttributeDefinition has a key attribute of "cocoa_brand" and the defining application ID is "abcd1234", this key is "abcd1234:cocoa_brand" when the application making the request is different from the application defining the custom attribute definition. Otherwise, the key is simply "cocoa_brand".
Implementations
Sourceimpl CatalogCustomAttributeValue
impl CatalogCustomAttributeValue
Sourcepub fn new() -> CatalogCustomAttributeValue
pub fn new() -> CatalogCustomAttributeValue
An instance of a custom attribute. Custom attributes can be defined and added to ITEM and ITEM_VARIATION type catalog objects. Read more about custom attributes.