pub struct CatalogQueryPrefix {
pub attribute_name: String,
pub attribute_prefix: String,
}Expand description
CatalogQueryPrefix : The query filter to return the search result whose named attribute values are prefixed by the specified attribute value.
Fields
attribute_name: StringThe name of the attribute to be searched.
attribute_prefix: StringThe desired prefix of the search attribute value.
Implementations
Sourceimpl CatalogQueryPrefix
impl CatalogQueryPrefix
Sourcepub fn new(
attribute_name: String,
attribute_prefix: String,
) -> CatalogQueryPrefix
pub fn new( attribute_name: String, attribute_prefix: String, ) -> CatalogQueryPrefix
The query filter to return the search result whose named attribute values are prefixed by the specified attribute value.