CatalogSubscriptionPlan

Struct CatalogSubscriptionPlan 

pub struct CatalogSubscriptionPlan {
    pub name: String,
    pub phases: Option<Option<Vec<SubscriptionPhase>>>,
    pub subscription_plan_variations: Option<Option<Vec<CatalogObject>>>,
    pub eligible_item_ids: Option<Option<Vec<String>>>,
    pub eligible_category_ids: Option<Option<Vec<String>>>,
    pub all_items: Option<Option<bool>>,
}
CatalogSubscriptionPlan : Describes a subscription plan. A subscription plan represents what you want to sell in a subscription model, and includes references to each of the associated subscription plan variations. For more information, see Subscription Plans and Variations.

Fields

name: String

The name of the plan.

phases: Option<Option<Vec<SubscriptionPhase>>>

A list of SubscriptionPhase containing the SubscriptionPhase for this plan. This field it required. Not including this field will throw a REQUIRED_FIELD_MISSING error

subscription_plan_variations: Option<Option<Vec<CatalogObject>>>

The list of subscription plan variations available for this product

eligible_item_ids: Option<Option<Vec<String>>>

The list of IDs of CatalogItems that are eligible for subscription by this SubscriptionPlan’s variations.

eligible_category_ids: Option<Option<Vec<String>>>

The list of IDs of CatalogCategory that are eligible for subscription by this SubscriptionPlan’s variations.

all_items: Option<Option<bool>>

If true, all items in the merchant’s catalog are subscribable by this SubscriptionPlan.

Implementations

Source

impl CatalogSubscriptionPlan

pub fn new(name: String) -> CatalogSubscriptionPlan

Describes a subscription plan. A subscription plan represents what you want to sell in a subscription model, and includes references to each of the associated subscription plan variations. For more information, see Subscription Plans and Variations.