pub struct CatalogVersionUpdatedEvent {
pub merchant_id: Option<Option<String>>,
pub type: Option<Option<String>>,
pub event_id: Option<Option<String>>,
pub created_at: Option<String>,
pub data: Option<Box<CatalogVersionUpdatedEventData>>,
}Expand description
CatalogVersionUpdatedEvent : Published when the catalog is updated.
Fields
merchant_id: Option<Option<String>>The ID of the target merchant associated with the event.
type: Option<Option<String>>The type of event this represents.
event_id: Option<Option<String>>A unique ID for the event.
created_at: Option<String>Timestamp of when the event was created, in RFC 3339 format.
data: Option<Box<CatalogVersionUpdatedEventData>>Implementations
Sourceimpl CatalogVersionUpdatedEvent
impl CatalogVersionUpdatedEvent
Sourcepub fn new() -> CatalogVersionUpdatedEvent
pub fn new() -> CatalogVersionUpdatedEvent
Published when the catalog is updated.