pub struct CloneOrderResponse {
pub order: Option<Box<Order>>,
pub errors: Option<Vec<Error>>,
}Expand description
CloneOrderResponse : Defines the fields that are included in the response body of a request to the CloneOrder endpoint.
Fields
order: Option<Box<Order>>errors: Option<Vec<Error>>Any errors that occurred during the request.
Implementations
Sourceimpl CloneOrderResponse
impl CloneOrderResponse
Sourcepub fn new() -> CloneOrderResponse
pub fn new() -> CloneOrderResponse
Defines the fields that are included in the response body of a request to the CloneOrder endpoint.