pub struct CreateCustomerCardResponse {
pub errors: Option<Vec<Error>>,
pub card: Option<Box<Card>>,
}Expand description
CreateCustomerCardResponse : Defines the fields that are included in the response body of a request to the CreateCustomerCard endpoint. Either errors or card is present in a given response (never both).
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
card: Option<Box<Card>>Implementations
Sourceimpl CreateCustomerCardResponse
impl CreateCustomerCardResponse
Sourcepub fn new() -> CreateCustomerCardResponse
pub fn new() -> CreateCustomerCardResponse
Defines the fields that are included in the response body of a request to the CreateCustomerCard endpoint. Either errors or card is present in a given response (never both).