pub struct CreateGiftCardActivityResponse {
pub errors: Option<Vec<Error>>,
pub gift_card_activity: Option<Box<GiftCardActivity>>,
}Expand description
CreateGiftCardActivityResponse : A response that contains a GiftCardActivity that was created. The response might contain a set of Error objects if the request resulted in errors.
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
gift_card_activity: Option<Box<GiftCardActivity>>Implementations
Sourceimpl CreateGiftCardActivityResponse
impl CreateGiftCardActivityResponse
Sourcepub fn new() -> CreateGiftCardActivityResponse
pub fn new() -> CreateGiftCardActivityResponse
A response that contains a GiftCardActivity that was created. The response might contain a set of Error objects if the request resulted in errors.