pub struct CreateGiftCardResponse {
pub errors: Option<Vec<Error>>,
pub gift_card: Option<Box<GiftCard>>,
}Expand description
CreateGiftCardResponse : A response that contains a GiftCard. The response might contain a set of Error objects if the request resulted in errors.
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
gift_card: Option<Box<GiftCard>>Implementations
Sourceimpl CreateGiftCardResponse
impl CreateGiftCardResponse
Sourcepub fn new() -> CreateGiftCardResponse
pub fn new() -> CreateGiftCardResponse
A response that contains a GiftCard. The response might contain a set of Error objects if the request resulted in errors.