pub struct CustomerCustomAttributeDefinitionCreatedEvent {
pub merchant_id: Option<Option<String>>,
pub type: Option<Option<String>>,
pub event_id: Option<Option<String>>,
pub created_at: Option<String>,
pub data: Option<Box<CustomAttributeDefinitionEventData>>,
}Expand description
CustomerCustomAttributeDefinitionCreatedEvent : Published when a customer custom attribute definition is created by the subscribing application. This event is replaced by customer.custom_attribute_definition.owned.created.
Fields
merchant_id: Option<Option<String>>The ID of the seller associated with the event that triggered the event notification.
type: Option<Option<String>>The type of this event. The value is \"customer.custom_attribute_definition.created\".
event_id: Option<Option<String>>A unique ID for the event notification.
created_at: Option<String>The timestamp that indicates when the event notification was created, in RFC 3339 format.
data: Option<Box<CustomAttributeDefinitionEventData>>Implementations
Sourceimpl CustomerCustomAttributeDefinitionCreatedEvent
impl CustomerCustomAttributeDefinitionCreatedEvent
Sourcepub fn new() -> CustomerCustomAttributeDefinitionCreatedEvent
pub fn new() -> CustomerCustomAttributeDefinitionCreatedEvent
Published when a customer custom attribute definition is created by the subscribing application. This event is replaced by customer.custom_attribute_definition.owned.created.