pub struct DeleteBookingCustomAttributeDefinitionResponse {
pub errors: Option<Vec<Error>>,
}Expand description
DeleteBookingCustomAttributeDefinitionResponse : Represents a DeleteBookingCustomAttributeDefinition response containing error messages when errors occurred during the request. The successful response does not contain any payload.
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
Implementations
Sourceimpl DeleteBookingCustomAttributeDefinitionResponse
impl DeleteBookingCustomAttributeDefinitionResponse
Sourcepub fn new() -> DeleteBookingCustomAttributeDefinitionResponse
pub fn new() -> DeleteBookingCustomAttributeDefinitionResponse
Represents a DeleteBookingCustomAttributeDefinition response containing error messages when errors occurred during the request. The successful response does not contain any payload.