pub struct DeleteCustomerGroupResponse {
pub errors: Option<Vec<Error>>,
}Expand description
DeleteCustomerGroupResponse : Defines the fields that are included in the response body of a request to the DeleteCustomerGroup endpoint.
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
Implementations
Sourceimpl DeleteCustomerGroupResponse
impl DeleteCustomerGroupResponse
Sourcepub fn new() -> DeleteCustomerGroupResponse
pub fn new() -> DeleteCustomerGroupResponse
Defines the fields that are included in the response body of a request to the DeleteCustomerGroup endpoint.