pub struct DeleteCustomerResponse {
pub errors: Option<Vec<Error>>,
}Expand description
DeleteCustomerResponse : Defines the fields that are included in the response body of a request to the DeleteCustomer endpoint.
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
Implementations
Sourceimpl DeleteCustomerResponse
impl DeleteCustomerResponse
Sourcepub fn new() -> DeleteCustomerResponse
pub fn new() -> DeleteCustomerResponse
Defines the fields that are included in the response body of a request to the DeleteCustomer endpoint.