pub struct DeleteMerchantCustomAttributeDefinitionResponse {
pub errors: Option<Vec<Error>>,
}Expand description
DeleteMerchantCustomAttributeDefinitionResponse : Represents a response from a delete request containing error messages if there are any.
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
Implementations
Sourceimpl DeleteMerchantCustomAttributeDefinitionResponse
impl DeleteMerchantCustomAttributeDefinitionResponse
Sourcepub fn new() -> DeleteMerchantCustomAttributeDefinitionResponse
pub fn new() -> DeleteMerchantCustomAttributeDefinitionResponse
Represents a response from a delete request containing error messages if there are any.