pub struct DeleteOrderCustomAttributeDefinitionResponse {
pub errors: Option<Vec<Error>>,
}Expand description
DeleteOrderCustomAttributeDefinitionResponse : Represents a response from deleting an order custom attribute definition.
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
Implementations
Sourceimpl DeleteOrderCustomAttributeDefinitionResponse
impl DeleteOrderCustomAttributeDefinitionResponse
Sourcepub fn new() -> DeleteOrderCustomAttributeDefinitionResponse
pub fn new() -> DeleteOrderCustomAttributeDefinitionResponse
Represents a response from deleting an order custom attribute definition.