pub struct DisableCardResponse {
pub errors: Option<Vec<Error>>,
pub card: Option<Box<Card>>,
}Expand description
DisableCardResponse : Defines the fields that are included in the response body of a request to the DisableCard endpoint. Note: if there are errors processing the request, the card field will not be present.
Fields
errors: Option<Vec<Error>>Information on errors encountered during the request.
card: Option<Box<Card>>Implementations
Sourceimpl DisableCardResponse
impl DisableCardResponse
Sourcepub fn new() -> DisableCardResponse
pub fn new() -> DisableCardResponse
Defines the fields that are included in the response body of a request to the DisableCard endpoint. Note: if there are errors processing the request, the card field will not be present.