GiftCardActivity

Struct GiftCardActivity 

pub struct GiftCardActivity {
Show 22 fields pub id: Option<String>, pub type: GiftCardActivityType, pub location_id: String, pub created_at: Option<String>, pub gift_card_id: Option<Option<String>>, pub gift_card_gan: Option<Option<String>>, pub gift_card_balance_money: Option<Box<Money>>, pub load_activity_details: Option<Box<GiftCardActivityLoad>>, pub activate_activity_details: Option<Box<GiftCardActivityActivate>>, pub redeem_activity_details: Option<Box<GiftCardActivityRedeem>>, pub clear_balance_activity_details: Option<Box<GiftCardActivityClearBalance>>, pub deactivate_activity_details: Option<Box<GiftCardActivityDeactivate>>, pub adjust_increment_activity_details: Option<Box<GiftCardActivityAdjustIncrement>>, pub adjust_decrement_activity_details: Option<Box<GiftCardActivityAdjustDecrement>>, pub refund_activity_details: Option<Box<GiftCardActivityRefund>>, pub unlinked_activity_refund_activity_details: Option<Box<GiftCardActivityUnlinkedActivityRefund>>, pub import_activity_details: Option<Box<GiftCardActivityImport>>, pub block_activity_details: Option<Box<GiftCardActivityBlock>>, pub unblock_activity_details: Option<Box<GiftCardActivityUnblock>>, pub import_reversal_activity_details: Option<Box<GiftCardActivityImportReversal>>, pub transfer_balance_to_activity_details: Option<Box<GiftCardActivityTransferBalanceTo>>, pub transfer_balance_from_activity_details: Option<Box<GiftCardActivityTransferBalanceFrom>>,
}
GiftCardActivity : Represents an action performed on a gift card that affects its state or balance. A gift card activity contains information about a specific activity type. For example, a REDEEM activity includes a redeem_activity_details field that contains information about the redemption.

Fields

id: Option<String>

The Square-assigned ID of the gift card activity.

type: GiftCardActivityTypelocation_id: String

The ID of the business location where the activity occurred.

created_at: Option<String>

The timestamp when the gift card activity was created, in RFC 3339 format.

gift_card_id: Option<Option<String>>

The gift card ID. When creating a gift card activity, gift_card_id is not required if gift_card_gan is specified.

gift_card_gan: Option<Option<String>>

The gift card account number (GAN). When creating a gift card activity, gift_card_gan is not required if gift_card_id is specified.

gift_card_balance_money: Option<Box<Money>>load_activity_details: Option<Box<GiftCardActivityLoad>>activate_activity_details: Option<Box<GiftCardActivityActivate>>redeem_activity_details: Option<Box<GiftCardActivityRedeem>>clear_balance_activity_details: Option<Box<GiftCardActivityClearBalance>>deactivate_activity_details: Option<Box<GiftCardActivityDeactivate>>adjust_increment_activity_details: Option<Box<GiftCardActivityAdjustIncrement>>adjust_decrement_activity_details: Option<Box<GiftCardActivityAdjustDecrement>>refund_activity_details: Option<Box<GiftCardActivityRefund>>unlinked_activity_refund_activity_details: Option<Box<GiftCardActivityUnlinkedActivityRefund>>import_activity_details: Option<Box<GiftCardActivityImport>>block_activity_details: Option<Box<GiftCardActivityBlock>>unblock_activity_details: Option<Box<GiftCardActivityUnblock>>import_reversal_activity_details: Option<Box<GiftCardActivityImportReversal>>transfer_balance_to_activity_details: Option<Box<GiftCardActivityTransferBalanceTo>>transfer_balance_from_activity_details: Option<Box<GiftCardActivityTransferBalanceFrom>>

Implementations

Source

impl GiftCardActivity

pub fn new(type: GiftCardActivityType, location_id: String) -> GiftCardActivity

Represents an action performed on a gift card that affects its state or balance. A gift card activity contains information about a specific activity type. For example, a REDEEM activity includes a redeem_activity_details field that contains information about the redemption.