pub struct GiftCardCustomerLinkedEventObject {
pub gift_card: Option<Box<GiftCard>>,
pub linked_customer_id: Option<Option<String>>,
}Expand description
GiftCardCustomerLinkedEventObject : An object that contains the gift card and customer ID associated with a gift_card.customer_linked event.
Fields
gift_card: Option<Box<GiftCard>>linked_customer_id: Option<Option<String>>The ID of the linked customer.
Implementations
Sourceimpl GiftCardCustomerLinkedEventObject
impl GiftCardCustomerLinkedEventObject
Sourcepub fn new() -> GiftCardCustomerLinkedEventObject
pub fn new() -> GiftCardCustomerLinkedEventObject
An object that contains the gift card and customer ID associated with a gift_card.customer_linked event.