pub struct GiftCardUpdatedEventObject {
pub gift_card: Option<Box<GiftCard>>,
}Expand description
GiftCardUpdatedEventObject : An object that contains the gift card associated with a gift_card.updated event.
Fields
gift_card: Option<Box<GiftCard>>Implementations
Sourceimpl GiftCardUpdatedEventObject
impl GiftCardUpdatedEventObject
Sourcepub fn new() -> GiftCardUpdatedEventObject
pub fn new() -> GiftCardUpdatedEventObject
An object that contains the gift card associated with a gift_card.updated event.