pub enum InventoryState {
Show 17 variants
Custom,
InStock,
Sold,
ReturnedByCustomer,
ReservedForSale,
SoldOnline,
OrderedFromVendor,
ReceivedFromVendor,
InTransitTo,
None,
Waste,
UnlinkedReturn,
Composed,
Decomposed,
SupportedByNewerVersion,
InTransit,
Untracked,
}Expand description
InventoryState : Indicates the state of a tracked item quantity in the lifecycle of goods. Indicates the state of a tracked item quantity in the lifecycle of goods.
Variants
Custom
InStock
Sold
ReturnedByCustomer
ReservedForSale
SoldOnline
OrderedFromVendor
ReceivedFromVendor
InTransitTo
None
Waste
UnlinkedReturn
Composed
Decomposed
SupportedByNewerVersion
InTransit
Untracked