pub struct InvoicePaymentMadeEvent {
pub merchant_id: Option<Option<String>>,
pub type: Option<Option<String>>,
pub event_id: Option<Option<String>>,
pub created_at: Option<String>,
pub data: Option<Box<InvoicePaymentMadeEventData>>,
}Expand description
InvoicePaymentMadeEvent : Published when a payment that is associated with an invoice is completed. For more information about invoice payments, see Pay an invoice.
Fields
merchant_id: Option<Option<String>>The ID of the target merchant associated with the event.
type: Option<Option<String>>The type of event this represents, \"invoice.payment_made\".
event_id: Option<Option<String>>A unique ID for the event.
created_at: Option<String>Timestamp of when the event was created, in RFC 3339 format.
data: Option<Box<InvoicePaymentMadeEventData>>Implementations
Sourceimpl InvoicePaymentMadeEvent
impl InvoicePaymentMadeEvent
Sourcepub fn new() -> InvoicePaymentMadeEvent
pub fn new() -> InvoicePaymentMadeEvent
Published when a payment that is associated with an invoice is completed. For more information about invoice payments, see Pay an invoice.