InvoicePaymentRequest

Struct InvoicePaymentRequest 

pub struct InvoicePaymentRequest {
Show 13 fields pub uid: Option<Option<String>>, pub request_method: Option<InvoiceRequestMethod>, pub request_type: Option<InvoiceRequestType>, pub due_date: Option<Option<String>>, pub fixed_amount_requested_money: Option<Box<Money>>, pub percentage_requested: Option<Option<String>>, pub tipping_enabled: Option<Option<bool>>, pub automatic_payment_source: Option<InvoiceAutomaticPaymentSource>, pub card_id: Option<Option<String>>, pub reminders: Option<Option<Vec<InvoicePaymentReminder>>>, pub computed_amount_money: Option<Box<Money>>, pub total_completed_amount_money: Option<Box<Money>>, pub rounding_adjustment_included_money: Option<Box<Money>>,
}
InvoicePaymentRequest : Represents a payment request for an invoice. Invoices can specify a maximum of 13 payment requests, with up to 12 INSTALLMENT request types. For more information, see Configuring payment requests. Adding INSTALLMENT payment requests to an invoice requires an Invoices Plus subscription.

Fields

uid: Option<Option<String>>

The Square-generated ID of the payment request in an invoice.

request_method: Option<InvoiceRequestMethod>request_type: Option<InvoiceRequestType>due_date: Option<Option<String>>

The due date (in the invoice’s time zone) for the payment request, in YYYY-MM-DD format. This field is required to create a payment request. If an automatic_payment_source is defined for the request, Square charges the payment source on this date. After this date, the invoice becomes overdue. For example, a payment due_date of 2021-03-09 with a timezone of America/Los\_Angeles becomes overdue at midnight on March 9 in America/Los\_Angeles (which equals a UTC timestamp of 2021-03-10T08:00:00Z).

fixed_amount_requested_money: Option<Box<Money>>percentage_requested: Option<Option<String>>

Specifies the amount for the payment request in percentage: - When the payment request_type is DEPOSIT, it is the percentage of the order’s total amount. - When the payment request_type is INSTALLMENT, it is the percentage of the order’s total less the deposit, if requested. The sum of the percentage_requested in all installment payment requests must be equal to 100. You cannot specify this when the payment request_type is BALANCE or when the payment request specifies the fixed_amount_requested_money field.

tipping_enabled: Option<Option<bool>>

If set to true, the Square-hosted invoice page (the public_url field of the invoice) provides a place for the customer to pay a tip. This field is allowed only on the final payment request and the payment request_type must be BALANCE or INSTALLMENT.

automatic_payment_source: Option<InvoiceAutomaticPaymentSource>card_id: Option<Option<String>>

The ID of the credit or debit card on file to charge for the payment request. To get the cards on file for a customer, call ListCards and include the customer_id of the invoice recipient.

reminders: Option<Option<Vec<InvoicePaymentReminder>>>

A list of one or more reminders to send for the payment request.

computed_amount_money: Option<Box<Money>>total_completed_amount_money: Option<Box<Money>>rounding_adjustment_included_money: Option<Box<Money>>

Implementations

Source

impl InvoicePaymentRequest

pub fn new() -> InvoicePaymentRequest

Represents a payment request for an invoice. Invoices can specify a maximum of 13 payment requests, with up to 12 INSTALLMENT request types. For more information, see Configuring payment requests. Adding INSTALLMENT payment requests to an invoice requires an Invoices Plus subscription.