pub struct InvoiceRefundedEvent {
pub merchant_id: Option<Option<String>>,
pub type: Option<Option<String>>,
pub event_id: Option<Option<String>>,
pub created_at: Option<String>,
pub data: Option<Box<InvoiceRefundedEventData>>,
}Expand description
InvoiceRefundedEvent : Published when a refund is applied toward a payment of an invoice. For more information about invoice refunds, see Refund an invoice.
Fields
merchant_id: Option<Option<String>>The ID of the target merchant associated with the event.
type: Option<Option<String>>The type of event this represents, \"invoice.refunded\".
event_id: Option<Option<String>>A unique ID for the event.
created_at: Option<String>Timestamp of when the event was created, in RFC 3339 format.
data: Option<Box<InvoiceRefundedEventData>>Implementations
Sourceimpl InvoiceRefundedEvent
impl InvoiceRefundedEvent
Sourcepub fn new() -> InvoiceRefundedEvent
pub fn new() -> InvoiceRefundedEvent
Published when a refund is applied toward a payment of an invoice. For more information about invoice refunds, see Refund an invoice.