pub struct InvoiceUpdatedEvent {
pub merchant_id: Option<Option<String>>,
pub type: Option<Option<String>>,
pub event_id: Option<Option<String>>,
pub created_at: Option<String>,
pub data: Option<Box<InvoiceUpdatedEventData>>,
}Expand description
InvoiceUpdatedEvent : Published when an Invoice is updated.
Fields
merchant_id: Option<Option<String>>The ID of the target merchant associated with the event.
type: Option<Option<String>>The type of event this represents, \"invoice.updated\".
event_id: Option<Option<String>>A unique ID for the event.
created_at: Option<String>Timestamp of when the event was created, in RFC 3339 format.
data: Option<Box<InvoiceUpdatedEventData>>Implementations
Sourceimpl InvoiceUpdatedEvent
impl InvoiceUpdatedEvent
Sourcepub fn new() -> InvoiceUpdatedEvent
pub fn new() -> InvoiceUpdatedEvent
Published when an Invoice is updated.