Job

Struct Job 

pub struct Job {
    pub id: Option<String>,
    pub title: Option<Option<String>>,
    pub is_tip_eligible: Option<Option<bool>>,
    pub created_at: Option<String>,
    pub updated_at: Option<String>,
    pub version: Option<i32>,
}
Job : Represents a job that can be assigned to team members. This object defines the job’s title and tip eligibility. Compensation is defined in a job assignment in a team member’s wage setting.

Fields

id: Option<String>

Read only The unique Square-assigned ID of the job. If you need a job ID for an API request, call ListJobs or use the ID returned when you created the job. You can also get job IDs from a team member’s wage setting.

title: Option<Option<String>>

The title of the job.

is_tip_eligible: Option<Option<bool>>

Indicates whether team members can earn tips for the job.

created_at: Option<String>

The timestamp when the job was created, in RFC 3339 format.

updated_at: Option<String>

The timestamp when the job was last updated, in RFC 3339 format.

version: Option<i32>

Read only The current version of the job. Include this field in UpdateJob requests to enable optimistic concurrency control and avoid overwrites from concurrent requests. Requests fail if the provided version doesn’t match the server version at the time of the request.

Implementations

Source

impl Job

pub fn new() -> Job

Represents a job that can be assigned to team members. This object defines the job’s title and tip eligibility. Compensation is defined in a job assignment in a team member’s wage setting.