ListCustomerCustomAttributesResponse

Struct ListCustomerCustomAttributesResponse 

pub struct ListCustomerCustomAttributesResponse {
    pub custom_attributes: Option<Vec<CustomAttribute>>,
    pub cursor: Option<String>,
    pub errors: Option<Vec<Error>>,
}
ListCustomerCustomAttributesResponse : Represents a ListCustomerCustomAttributes response. Either custom_attributes, an empty object, or errors is present in the response. If additional results are available, the cursor field is also present along with custom_attributes.

Fields

custom_attributes: Option<Vec<CustomAttribute>>

The retrieved custom attributes. If with_definitions was set to true in the request, the custom attribute definition is returned in the definition field of each custom attribute. If no custom attributes are found, Square returns an empty object ({}).

cursor: Option<String>

The cursor to use in your next call to this endpoint to retrieve the next page of results for your original request. This field is present only if the request succeeded and additional results are available. For more information, see Pagination.

errors: Option<Vec<Error>>

Any errors that occurred during the request.

Implementations

Source

impl ListCustomerCustomAttributesResponse

pub fn new() -> ListCustomerCustomAttributesResponse

Represents a ListCustomerCustomAttributes response. Either custom_attributes, an empty object, or errors is present in the response. If additional results are available, the cursor field is also present along with custom_attributes.