ListCustomerGroupsResponse

Struct ListCustomerGroupsResponse 

pub struct ListCustomerGroupsResponse {
    pub errors: Option<Vec<Error>>,
    pub groups: Option<Vec<CustomerGroup>>,
    pub cursor: Option<String>,
}
ListCustomerGroupsResponse : Defines the fields that are included in the response body of a request to the ListCustomerGroups endpoint. Either errors or groups is present in a given response (never both).

Fields

errors: Option<Vec<Error>>

Any errors that occurred during the request.

groups: Option<Vec<CustomerGroup>>

A list of customer groups belonging to the current seller.

cursor: Option<String>

A pagination cursor to retrieve the next set of results for your original query to the endpoint. This value is present only if the request succeeded and additional results are available. For more information, see Pagination.

Implementations

Source

impl ListCustomerGroupsResponse

pub fn new() -> ListCustomerGroupsResponse

Defines the fields that are included in the response body of a request to the ListCustomerGroups endpoint. Either errors or groups is present in a given response (never both).