ListOrderCustomAttributesResponse

Struct ListOrderCustomAttributesResponse 

pub struct ListOrderCustomAttributesResponse {
    pub custom_attributes: Option<Vec<CustomAttribute>>,
    pub cursor: Option<String>,
    pub errors: Option<Vec<Error>>,
}
ListOrderCustomAttributesResponse : Represents a response from listing order custom attributes.

Fields

custom_attributes: Option<Vec<CustomAttribute>>

The retrieved custom attributes. If no custom attribute are found, Square returns an empty object ({}).

cursor: Option<String>

The cursor to provide in your next call to this endpoint to retrieve the next page of results for your original request. This field is present only if the request succeeded and additional results are available. For more information, see Pagination.

errors: Option<Vec<Error>>

Any errors that occurred during the request.

Implementations

Source

impl ListOrderCustomAttributesResponse

pub fn new() -> ListOrderCustomAttributesResponse

Represents a response from listing order custom attributes.