pub struct ListTransactionsResponse {
pub errors: Option<Vec<Error>>,
pub transactions: Option<Vec<Transaction>>,
pub cursor: Option<String>,
}Expand description
ListTransactionsResponse : Defines the fields that are included in the response body of a request to the ListTransactions endpoint. One of errors or transactions is present in a given response (never both).
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
transactions: Option<Vec<Transaction>>An array of transactions that match your query.
cursor: Option<String>A pagination cursor for retrieving the next set of results, if any remain. Provide this value as the cursor parameter in a subsequent request to this endpoint. See Paginating results for more information.
Implementations
Sourceimpl ListTransactionsResponse
impl ListTransactionsResponse
Sourcepub fn new() -> ListTransactionsResponse
pub fn new() -> ListTransactionsResponse
Defines the fields that are included in the response body of a request to the ListTransactions endpoint. One of errors or transactions is present in a given response (never both).