pub struct ListWorkweekConfigsResponse {
pub workweek_configs: Option<Vec<WorkweekConfig>>,
pub cursor: Option<String>,
pub errors: Option<Vec<Error>>,
}Expand description
ListWorkweekConfigsResponse : The response to a request for a set of WorkweekConfig objects. The response contains the requested WorkweekConfig objects and might contain a set of Error objects if the request resulted in errors.
Fields
workweek_configs: Option<Vec<WorkweekConfig>>A page of WorkweekConfig results.
cursor: Option<String>The value supplied in the subsequent request to fetch the next page of WorkweekConfig results.
errors: Option<Vec<Error>>Any errors that occurred during the request.
Implementations
Sourceimpl ListWorkweekConfigsResponse
impl ListWorkweekConfigsResponse
Sourcepub fn new() -> ListWorkweekConfigsResponse
pub fn new() -> ListWorkweekConfigsResponse
The response to a request for a set of WorkweekConfig objects. The response contains the requested WorkweekConfig objects and might contain a set of Error objects if the request resulted in errors.