LocationCustomAttributeOwnedUpdatedEvent

Struct LocationCustomAttributeOwnedUpdatedEvent 

pub struct LocationCustomAttributeOwnedUpdatedEvent {
    pub merchant_id: Option<Option<String>>,
    pub type: Option<Option<String>>,
    pub event_id: Option<Option<String>>,
    pub created_at: Option<String>,
    pub data: Option<Box<CustomAttributeEventData>>,
}
LocationCustomAttributeOwnedUpdatedEvent : Published when a location custom attribute owned by the subscribing application is created or updated. Custom attributes are owned by the application that created the corresponding custom attribute definition. Custom attributes whose visibility is VISIBILITY_READ_WRITE_VALUES can be created or updated by any application.

Fields

merchant_id: Option<Option<String>>

The ID of the seller associated with the event that triggered the event notification.

type: Option<Option<String>>

The type of this event. The value is \"location.custom_attribute.owned.updated\".

event_id: Option<Option<String>>

A unique ID for the event notification.

created_at: Option<String>

The timestamp that indicates when the event notification was created, in RFC 3339 format.

data: Option<Box<CustomAttributeEventData>>

Implementations

Source

impl LocationCustomAttributeOwnedUpdatedEvent

pub fn new() -> LocationCustomAttributeOwnedUpdatedEvent

Published when a location custom attribute owned by the subscribing application is created or updated. Custom attributes are owned by the application that created the corresponding custom attribute definition. Custom attributes whose visibility is VISIBILITY_READ_WRITE_VALUES can be created or updated by any application.