pub struct LocationCustomAttributeVisibleUpdatedEvent {
pub merchant_id: Option<Option<String>>,
pub type: Option<Option<String>>,
pub event_id: Option<Option<String>>,
pub created_at: Option<String>,
pub data: Option<Box<CustomAttributeEventData>>,
}Expand description
LocationCustomAttributeVisibleUpdatedEvent : Published when a location custom attribute that is visible to the subscribing application is created or updated. A notification is sent when: - Your application creates or updates a custom attribute owned by your application, regardless of the visibility setting. - Any application creates or updates a custom attribute whose visibility is VISIBILITY_READ_ONLY or VISIBILITY_READ_WRITE_VALUES. Custom attributes set to VISIBILITY_READ_WRITE_VALUES can be created or updated by any application, but those set to VISIBILITY_READ_ONLY or VISIBILITY_HIDDEN can only be created or updated by the owner. Custom attributes are owned by the application that created the corresponding custom attribute definition.
Fields
merchant_id: Option<Option<String>>The ID of the seller associated with the event that triggered the event notification.
type: Option<Option<String>>The type of this event. The value is \"location.custom_attribute.visible.updated\".
event_id: Option<Option<String>>A unique ID for the event notification.
created_at: Option<String>The timestamp that indicates when the event notification was created, in RFC 3339 format.
data: Option<Box<CustomAttributeEventData>>Implementations
Sourceimpl LocationCustomAttributeVisibleUpdatedEvent
impl LocationCustomAttributeVisibleUpdatedEvent
Sourcepub fn new() -> LocationCustomAttributeVisibleUpdatedEvent
pub fn new() -> LocationCustomAttributeVisibleUpdatedEvent
Published when a location custom attribute that is visible to the subscribing application is created or updated. A notification is sent when: - Your application creates or updates a custom attribute owned by your application, regardless of the visibility setting. - Any application creates or updates a custom attribute whose visibility is VISIBILITY_READ_ONLY or VISIBILITY_READ_WRITE_VALUES. Custom attributes set to VISIBILITY_READ_WRITE_VALUES can be created or updated by any application, but those set to VISIBILITY_READ_ONLY or VISIBILITY_HIDDEN can only be created or updated by the owner. Custom attributes are owned by the application that created the corresponding custom attribute definition.