pub struct LocationUpdatedEvent {
pub merchant_id: Option<Option<String>>,
pub location_id: Option<Option<String>>,
pub type: Option<Option<String>>,
pub event_id: Option<Option<String>>,
pub created_at: Option<String>,
pub data: Option<Box<LocationUpdatedEventData>>,
}Expand description
LocationUpdatedEvent : Published when a Location is updated.
Fields
merchant_id: Option<Option<String>>The ID of the target merchant associated with the event.
location_id: Option<Option<String>>The ID of the Location associated with the event.
type: Option<Option<String>>The type of event this represents, \"location.updated\".
event_id: Option<Option<String>>A unique ID for the event.
created_at: Option<String>Timestamp of when the event was created, in RFC 3339 format.
data: Option<Box<LocationUpdatedEventData>>Implementations
Sourceimpl LocationUpdatedEvent
impl LocationUpdatedEvent
Sourcepub fn new() -> LocationUpdatedEvent
pub fn new() -> LocationUpdatedEvent
Published when a Location is updated.