pub struct LoyaltyProgramCreatedEventObject {
pub loyalty_program: Option<Box<LoyaltyProgram>>,
}Expand description
LoyaltyProgramCreatedEventObject : An object that contains the loyalty program associated with a loyalty.program.created event.
Fields
loyalty_program: Option<Box<LoyaltyProgram>>Implementations
Sourceimpl LoyaltyProgramCreatedEventObject
impl LoyaltyProgramCreatedEventObject
Sourcepub fn new() -> LoyaltyProgramCreatedEventObject
pub fn new() -> LoyaltyProgramCreatedEventObject
An object that contains the loyalty program associated with a loyalty.program.created event.