pub enum MeasurementUnitTime {
GenericMillisecond,
GenericSecond,
GenericMinute,
GenericHour,
GenericDay,
}Expand description
MeasurementUnitTime : Unit of time used to measure a quantity (a duration). Unit of time used to measure a quantity (a duration).
Variants