pub enum MeasurementUnitVolume {
GenericFluidOunce,
GenericShot,
GenericCup,
GenericPint,
GenericQuart,
GenericGallon,
ImperialCubicInch,
ImperialCubicFoot,
ImperialCubicYard,
MetricMilliliter,
MetricLiter,
}Expand description
MeasurementUnitVolume : The unit of volume used to measure a quantity. The unit of volume used to measure a quantity.
Variants
GenericFluidOunce
GenericShot
GenericCup
GenericPint
GenericQuart
GenericGallon
ImperialCubicInch
ImperialCubicFoot
ImperialCubicYard
MetricMilliliter
MetricLiter