pub struct OrderCustomAttributeDefinitionVisibleCreatedEvent {
pub merchant_id: Option<Option<String>>,
pub type: Option<Option<String>>,
pub event_id: Option<Option<String>>,
pub created_at: Option<String>,
pub data: Option<Box<CustomAttributeDefinitionEventData>>,
}Expand description
OrderCustomAttributeDefinitionVisibleCreatedEvent : Published when an order custom attribute definition that is visible to the subscribing app is created.
Fields
merchant_id: Option<Option<String>>The ID of the target seller associated with the event.
type: Option<Option<String>>The type of this event. The value is \"order.custom_attribute_definition.visible.created\".
event_id: Option<Option<String>>A unique ID for the event.
created_at: Option<String>The timestamp of when the event was created, in RFC 3339 format.
data: Option<Box<CustomAttributeDefinitionEventData>>Implementations
Sourceimpl OrderCustomAttributeDefinitionVisibleCreatedEvent
impl OrderCustomAttributeDefinitionVisibleCreatedEvent
Sourcepub fn new() -> OrderCustomAttributeDefinitionVisibleCreatedEvent
pub fn new() -> OrderCustomAttributeDefinitionVisibleCreatedEvent
Published when an order custom attribute definition that is visible to the subscribing app is created.