pub struct OrderCustomAttributeVisibleUpdatedEvent {
pub merchant_id: Option<Option<String>>,
pub type: Option<Option<String>>,
pub event_id: Option<Option<String>>,
pub created_at: Option<String>,
pub data: Option<Box<CustomAttributeEventData>>,
}Expand description
OrderCustomAttributeVisibleUpdatedEvent : Published when an order custom attribute that is visible to the subscribing app is updated.
Fields
merchant_id: Option<Option<String>>The ID of the target seller associated with the event.
type: Option<Option<String>>The type of this event. The value is \"order.custom_attribute.visible.updated\".
event_id: Option<Option<String>>A unique ID for the event.
created_at: Option<String>The timestamp of when the event was created, in RFC 3339 format.
data: Option<Box<CustomAttributeEventData>>Implementations
Sourceimpl OrderCustomAttributeVisibleUpdatedEvent
impl OrderCustomAttributeVisibleUpdatedEvent
Sourcepub fn new() -> OrderCustomAttributeVisibleUpdatedEvent
pub fn new() -> OrderCustomAttributeVisibleUpdatedEvent
Published when an order custom attribute that is visible to the subscribing app is updated.