OrderPricingOptions

Struct OrderPricingOptions 

pub struct OrderPricingOptions {
    pub auto_apply_discounts: Option<Option<bool>>,
    pub auto_apply_taxes: Option<Option<bool>>,
}
OrderPricingOptions : Pricing options for an order. The options affect how the order’s price is calculated. They can be used, for example, to apply automatic price adjustments that are based on preconfigured pricing rules.

Fields

auto_apply_discounts: Option<Option<bool>>

The option to determine whether pricing rule-based discounts are automatically applied to an order.

auto_apply_taxes: Option<Option<bool>>

The option to determine whether rule-based taxes are automatically applied to an order when the criteria of the corresponding rules are met.

Implementations

Source

impl OrderPricingOptions

pub fn new() -> OrderPricingOptions

Pricing options for an order. The options affect how the order’s price is calculated. They can be used, for example, to apply automatic price adjustments that are based on preconfigured pricing rules.