OrderReward

Struct OrderReward 

pub struct OrderReward {
    pub id: String,
    pub reward_tier_id: String,
}
OrderReward : Represents a reward that can be applied to an order if the necessary reward tier criteria are met. Rewards are created through the Loyalty API.

Fields

id: String

The identifier of the reward.

reward_tier_id: String

The identifier of the reward tier corresponding to this reward.

Implementations

Source

impl OrderReward

pub fn new(id: String, reward_tier_id: String) -> OrderReward

Represents a reward that can be applied to an order if the necessary reward tier criteria are met. Rewards are created through the Loyalty API.