pub struct OrderUpdatedEvent {
pub merchant_id: Option<Option<String>>,
pub type: Option<Option<String>>,
pub event_id: Option<Option<String>>,
pub created_at: Option<String>,
pub data: Option<Box<OrderUpdatedEventData>>,
}Expand description
OrderUpdatedEvent : Published when an Order is updated. This event is triggered by the UpdateOrder endpoint call, Order Manager, or the Square Dashboard.
Fields
merchant_id: Option<Option<String>>The ID of the target merchant associated with the event.
type: Option<Option<String>>The type of event this represents, \"order.updated\".
event_id: Option<Option<String>>A unique ID for the event.
created_at: Option<String>Timestamp of when the event was created, in RFC 3339 format.
data: Option<Box<OrderUpdatedEventData>>Implementations
Sourceimpl OrderUpdatedEvent
impl OrderUpdatedEvent
Sourcepub fn new() -> OrderUpdatedEvent
pub fn new() -> OrderUpdatedEvent
Published when an Order is updated. This event is triggered by the UpdateOrder endpoint call, Order Manager, or the Square Dashboard.