pub struct PaymentLink {
pub id: Option<String>,
pub version: i32,
pub description: Option<Option<String>>,
pub order_id: Option<String>,
pub checkout_options: Option<Box<CheckoutOptions>>,
pub pre_populated_data: Option<Box<PrePopulatedData>>,
pub url: Option<String>,
pub long_url: Option<String>,
pub created_at: Option<String>,
pub updated_at: Option<String>,
pub payment_note: Option<Option<String>>,
}Fields
id: Option<String>The Square-assigned ID of the payment link.
version: i32The Square-assigned version number, which is incremented each time an update is committed to the payment link.
description: Option<Option<String>>The optional description of the payment_link object. It is primarily for use by your application and is not used anywhere.
order_id: Option<String>The ID of the order associated with the payment link.
checkout_options: Option<Box<CheckoutOptions>>pre_populated_data: Option<Box<PrePopulatedData>>url: Option<String>The shortened URL of the payment link.
long_url: Option<String>The long URL of the payment link.
created_at: Option<String>The timestamp when the payment link was created, in RFC 3339 format.
updated_at: Option<String>The timestamp when the payment link was last updated, in RFC 3339 format.
payment_note: Option<Option<String>>An optional note. After Square processes the payment, this note is added to the resulting Payment.
Implementations
Sourceimpl PaymentLink
impl PaymentLink
pub fn new(version: i32) -> PaymentLink