pub struct PaymentOptions {
pub autocomplete: Option<Option<bool>>,
pub delay_duration: Option<Option<String>>,
pub accept_partial_authorization: Option<Option<bool>>,
pub delay_action: Option<PaymentOptionsDelayAction>,
}Fields
autocomplete: Option<Option<bool>>Indicates whether the Payment objects created from this TerminalCheckout are automatically COMPLETED or left in an APPROVED state for later modification. Default: true
delay_duration: Option<Option<String>>The duration of time after the payment’s creation when Square automatically resolves the payment. This automatic resolution applies only to payments that do not reach a terminal state (COMPLETED or CANCELED) before the delay_duration time period. This parameter should be specified as a time duration, in RFC 3339 format, with a minimum value of 1 minute and a maximum value of 36 hours. This feature is only supported for card payments, and all payments will be considered card-present. This parameter can only be set for a delayed capture payment (autocomplete=false). For more information, see Delayed Capture. Default: "PT36H" (36 hours) from the creation time
If set to true and charging a Square Gift Card, a payment might be returned with amount_money equal to less than what was requested. For example, a request for $20 when charging a Square Gift Card with a balance of $5 results in an APPROVED payment of $5. You might choose to prompt the buyer for an additional payment to cover the remainder or cancel the Gift Card payment. This parameter can only be set for a delayed capture payment (autocomplete=false). For more information, see Take Partial Payments. Default: false
delay_action: Option<PaymentOptionsDelayAction>Implementations
Sourceimpl PaymentOptions
impl PaymentOptions
pub fn new() -> PaymentOptions