RefundPaymentRequest

Struct RefundPaymentRequest 

pub struct RefundPaymentRequest {
Show 14 fields pub idempotency_key: String, pub amount_money: Box<Money>, pub app_fee_money: Option<Box<Money>>, pub app_fee_allocations: Option<Option<Vec<Value>>>, pub payment_id: Option<Option<String>>, pub destination_id: Option<Option<String>>, pub unlinked: Option<Option<bool>>, pub location_id: Option<Option<String>>, pub customer_id: Option<Option<String>>, pub reason: Option<Option<String>>, pub payment_version_token: Option<Option<String>>, pub team_member_id: Option<Option<String>>, pub cash_details: Option<Box<DestinationDetailsCashRefundDetails>>, pub external_details: Option<Box<DestinationDetailsExternalRefundDetails>>,
}
RefundPaymentRequest : Describes a request to refund a payment using RefundPayment.

Fields

idempotency_key: String

A unique string that identifies this RefundPayment request. The key can be any valid string but must be unique for every RefundPayment request. Keys are limited to a max of 45 characters - however, the number of allowed characters might be less than 45, if multi-byte characters are used. For more information, see Idempotency.

amount_money: Box<Money>app_fee_money: Option<Box<Money>>app_fee_allocations: Option<Option<Vec<Value>>>

Details pertaining to contributors to the refund of the application fee. The sum of the amounts in the app_fee_allocations must equal the app_fee_money amount, if present. If populated, an allocation must be present for every party that expects to contribute a portion of the refunded application fee, including the application developer.

payment_id: Option<Option<String>>

The unique ID of the payment being refunded. Required when unlinked=false, otherwise must not be set.

destination_id: Option<Option<String>>

The ID indicating where funds will be refunded to. Required for unlinked refunds. For more information, see Process an Unlinked Refund. For refunds linked to Square payments, destination_id is usually omitted; in this case, funds will be returned to the original payment source. The field may be specified in order to request a cross-method refund to a gift card. For more information, see Cross-method refunds to gift cards.

unlinked: Option<Option<bool>>

Indicates that the refund is not linked to a Square payment. If set to true, destination_id and location_id must be supplied while payment_id must not be provided.

location_id: Option<Option<String>>

The location ID associated with the unlinked refund. Required for requests specifying unlinked=true. Otherwise, if included when unlinked=false, will throw an error.

customer_id: Option<Option<String>>

The Customer ID of the customer associated with the refund. This is required if the destination_id refers to a card on file created using the Cards API. Only allowed when unlinked=true.

reason: Option<Option<String>>

A description of the reason for the refund.

payment_version_token: Option<Option<String>>

Used for optimistic concurrency. This opaque token identifies the current Payment version that the caller expects. If the server has a different version of the Payment, the update fails and a response with a VERSION_MISMATCH error is returned. If the versions match, or the field is not provided, the refund proceeds as normal.

team_member_id: Option<Option<String>>

An optional TeamMember ID to associate with this refund.

cash_details: Option<Box<DestinationDetailsCashRefundDetails>>external_details: Option<Box<DestinationDetailsExternalRefundDetails>>

Implementations

Source

impl RefundPaymentRequest

pub fn new(idempotency_key: String, amount_money: Money) -> RefundPaymentRequest

Describes a request to refund a payment using RefundPayment.