pub struct RefundPaymentResponse {
pub errors: Option<Vec<Error>>,
pub refund: Option<Box<PaymentRefund>>,
}Expand description
RefundPaymentResponse : Defines the response returned by RefundPayment. If there are errors processing the request, the refund field might not be present, or it might be present with a status of FAILED.
Fields
errors: Option<Vec<Error>>Information about errors encountered during the request.
refund: Option<Box<PaymentRefund>>Implementations
Sourceimpl RefundPaymentResponse
impl RefundPaymentResponse
Sourcepub fn new() -> RefundPaymentResponse
pub fn new() -> RefundPaymentResponse
Defines the response returned by RefundPayment. If there are errors processing the request, the refund field might not be present, or it might be present with a status of FAILED.