pub struct RefundUpdatedEvent {
pub merchant_id: Option<Option<String>>,
pub type: Option<Option<String>>,
pub event_id: Option<Option<String>>,
pub created_at: Option<String>,
pub data: Option<Box<RefundUpdatedEventData>>,
}Expand description
RefundUpdatedEvent : Published when a Refund is updated. Typically the refund.status changes when a refund is completed.
Fields
merchant_id: Option<Option<String>>The ID of the target merchant associated with the event.
type: Option<Option<String>>The type of event this represents, \"refund.updated\".
event_id: Option<Option<String>>A unique ID for the event.
created_at: Option<String>Timestamp of when the event was created, in RFC 3339 format.
data: Option<Box<RefundUpdatedEventData>>Implementations
Sourceimpl RefundUpdatedEvent
impl RefundUpdatedEvent
Sourcepub fn new() -> RefundUpdatedEvent
pub fn new() -> RefundUpdatedEvent
Published when a Refund is updated. Typically the refund.status changes when a refund is completed.