pub struct RetrieveCardResponse {
pub errors: Option<Vec<Error>>,
pub card: Option<Box<Card>>,
}Expand description
RetrieveCardResponse : Defines the fields that are included in the response body of a request to the RetrieveCard endpoint. Note: if there are errors processing the request, the card field will not be present.
Fields
errors: Option<Vec<Error>>Information on errors encountered during the request.
card: Option<Box<Card>>Implementations
Sourceimpl RetrieveCardResponse
impl RetrieveCardResponse
Sourcepub fn new() -> RetrieveCardResponse
pub fn new() -> RetrieveCardResponse
Defines the fields that are included in the response body of a request to the RetrieveCard endpoint. Note: if there are errors processing the request, the card field will not be present.