pub struct RetrieveCustomerResponse {
pub errors: Option<Vec<Error>>,
pub customer: Option<Box<Customer>>,
}Expand description
RetrieveCustomerResponse : Defines the fields that are included in the response body of a request to the RetrieveCustomer endpoint. Either errors or customer is present in a given response (never both).
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
customer: Option<Box<Customer>>Implementations
Sourceimpl RetrieveCustomerResponse
impl RetrieveCustomerResponse
Sourcepub fn new() -> RetrieveCustomerResponse
pub fn new() -> RetrieveCustomerResponse
Defines the fields that are included in the response body of a request to the RetrieveCustomer endpoint. Either errors or customer is present in a given response (never both).