pub struct RetrieveCustomerSegmentResponse {
pub errors: Option<Vec<Error>>,
pub segment: Option<Box<CustomerSegment>>,
}Expand description
RetrieveCustomerSegmentResponse : Defines the fields that are included in the response body for requests to the RetrieveCustomerSegment endpoint. Either errors or segment is present in a given response (never both).
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
segment: Option<Box<CustomerSegment>>Implementations
Sourceimpl RetrieveCustomerSegmentResponse
impl RetrieveCustomerSegmentResponse
Sourcepub fn new() -> RetrieveCustomerSegmentResponse
pub fn new() -> RetrieveCustomerSegmentResponse
Defines the fields that are included in the response body for requests to the RetrieveCustomerSegment endpoint. Either errors or segment is present in a given response (never both).