pub struct RetrieveJobResponse {
pub job: Option<Box<Job>>,
pub errors: Option<Vec<Error>>,
}Expand description
RetrieveJobResponse : Represents a RetrieveJob response. Either job or errors is present in the response.
Fields
job: Option<Box<Job>>errors: Option<Vec<Error>>The errors that occurred during the request.
Implementations
Sourceimpl RetrieveJobResponse
impl RetrieveJobResponse
Sourcepub fn new() -> RetrieveJobResponse
pub fn new() -> RetrieveJobResponse
Represents a RetrieveJob response. Either job or errors is present in the response.