pub struct RetrieveOrderCustomAttributeDefinitionResponse {
pub custom_attribute_definition: Option<Box<CustomAttributeDefinition>>,
pub errors: Option<Vec<Error>>,
}Expand description
RetrieveOrderCustomAttributeDefinitionResponse : Represents a response from getting an order custom attribute definition.
Fields
custom_attribute_definition: Option<Box<CustomAttributeDefinition>>errors: Option<Vec<Error>>Any errors that occurred during the request.
Implementations
Sourceimpl RetrieveOrderCustomAttributeDefinitionResponse
impl RetrieveOrderCustomAttributeDefinitionResponse
Sourcepub fn new() -> RetrieveOrderCustomAttributeDefinitionResponse
pub fn new() -> RetrieveOrderCustomAttributeDefinitionResponse
Represents a response from getting an order custom attribute definition.