pub struct RetrieveTeamMemberResponse {
pub team_member: Option<Box<TeamMember>>,
pub errors: Option<Vec<Error>>,
}Expand description
RetrieveTeamMemberResponse : Represents a response from a retrieve request containing a TeamMember object or error messages.
Fields
team_member: Option<Box<TeamMember>>errors: Option<Vec<Error>>The errors that occurred during the request.
Implementations
Sourceimpl RetrieveTeamMemberResponse
impl RetrieveTeamMemberResponse
Sourcepub fn new() -> RetrieveTeamMemberResponse
pub fn new() -> RetrieveTeamMemberResponse
Represents a response from a retrieve request containing a TeamMember object or error messages.