pub struct RetrieveTransactionResponse {
pub errors: Option<Vec<Error>>,
pub transaction: Option<Box<Transaction>>,
}Expand description
RetrieveTransactionResponse : Defines the fields that are included in the response body of a request to the RetrieveTransaction endpoint. One of errors or transaction is present in a given response (never both).
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
transaction: Option<Box<Transaction>>Implementations
Sourceimpl RetrieveTransactionResponse
impl RetrieveTransactionResponse
Sourcepub fn new() -> RetrieveTransactionResponse
pub fn new() -> RetrieveTransactionResponse
Defines the fields that are included in the response body of a request to the RetrieveTransaction endpoint. One of errors or transaction is present in a given response (never both).