pub struct RetrieveWebhookSubscriptionResponse {
pub errors: Option<Vec<Error>>,
pub subscription: Option<Box<WebhookSubscription>>,
}Expand description
RetrieveWebhookSubscriptionResponse : Defines the fields that are included in the response body of a request to the RetrieveWebhookSubscription endpoint. Note: if there are errors processing the request, the Subscription will not be present.
Fields
errors: Option<Vec<Error>>Information on errors encountered during the request.
subscription: Option<Box<WebhookSubscription>>Implementations
Sourceimpl RetrieveWebhookSubscriptionResponse
impl RetrieveWebhookSubscriptionResponse
Sourcepub fn new() -> RetrieveWebhookSubscriptionResponse
pub fn new() -> RetrieveWebhookSubscriptionResponse
Defines the fields that are included in the response body of a request to the RetrieveWebhookSubscription endpoint. Note: if there are errors processing the request, the Subscription will not be present.