pub struct ScheduledShift {
pub id: Option<String>,
pub draft_shift_details: Option<Box<ScheduledShiftDetails>>,
pub published_shift_details: Option<Box<ScheduledShiftDetails>>,
pub version: Option<i32>,
pub created_at: Option<String>,
pub updated_at: Option<String>,
}Expand description
ScheduledShift : Represents a specific time slot in a work schedule. This object is used to manage the lifecycle of a scheduled shift from the draft to published state. A scheduled shift contains the latest draft shift details and current published shift details.
Fields
id: Option<String>Read only The Square-issued ID of the scheduled shift.
draft_shift_details: Option<Box<ScheduledShiftDetails>>published_shift_details: Option<Box<ScheduledShiftDetails>>version: Option<i32>Read only The current version of the scheduled shift, which is incremented with each update. This field is used for optimistic concurrency control to ensure that requests don’t overwrite data from another request.
created_at: Option<String>The timestamp of when the scheduled shift was created, in RFC 3339 format presented as UTC.
updated_at: Option<String>The timestamp of when the scheduled shift was last updated, in RFC 3339 format presented as UTC.
Implementations
Sourceimpl ScheduledShift
impl ScheduledShift
Sourcepub fn new() -> ScheduledShift
pub fn new() -> ScheduledShift
Represents a specific time slot in a work schedule. This object is used to manage the lifecycle of a scheduled shift from the draft to published state. A scheduled shift contains the latest draft shift details and current published shift details.