SearchCatalogItemsRequest

Struct SearchCatalogItemsRequest 

pub struct SearchCatalogItemsRequest {
    pub text_filter: Option<String>,
    pub category_ids: Option<Vec<String>>,
    pub stock_levels: Option<Vec<SearchCatalogItemsRequestStockLevel>>,
    pub enabled_location_ids: Option<Vec<String>>,
    pub cursor: Option<String>,
    pub limit: Option<i32>,
    pub sort_order: Option<SortOrder>,
    pub product_types: Option<Vec<CatalogItemProductType>>,
    pub custom_attribute_filters: Option<Vec<CustomAttributeFilter>>,
    pub archived_state: Option<ArchivedState>,
}
SearchCatalogItemsRequest : Defines the request body for the SearchCatalogItems endpoint.

Fields

text_filter: Option<String>

The text filter expression to return items or item variations containing specified text in the name, description, or abbreviation attribute value of an item, or in the name, sku, or upc attribute value of an item variation.

category_ids: Option<Vec<String>>

The category id query expression to return items containing the specified category IDs.

stock_levels: Option<Vec<SearchCatalogItemsRequestStockLevel>>

The stock-level query expression to return item variations with the specified stock levels. See SearchCatalogItemsRequestStockLevel for possible values

enabled_location_ids: Option<Vec<String>>

The enabled-location query expression to return items and item variations having specified enabled locations.

cursor: Option<String>

The pagination token, returned in the previous response, used to fetch the next batch of pending results.

limit: Option<i32>

The maximum number of results to return per page. The default value is 100.

sort_order: Option<SortOrder>product_types: Option<Vec<CatalogItemProductType>>

The product types query expression to return items or item variations having the specified product types.

custom_attribute_filters: Option<Vec<CustomAttributeFilter>>

The customer-attribute filter to return items or item variations matching the specified custom attribute expressions. A maximum number of 10 custom attribute expressions are supported in a single call to the SearchCatalogItems endpoint.

archived_state: Option<ArchivedState>

Implementations

Source

impl SearchCatalogItemsRequest

pub fn new() -> SearchCatalogItemsRequest

Defines the request body for the SearchCatalogItems endpoint.