pub struct SearchEventsResponse {
pub errors: Option<Vec<Error>>,
pub events: Option<Vec<Event>>,
pub metadata: Option<Vec<EventMetadata>>,
pub cursor: Option<String>,
}Expand description
SearchEventsResponse : Defines the fields that are included in the response body of a request to the SearchEvents endpoint. Note: if there are errors processing the request, the events field will not be present.
Fields
errors: Option<Vec<Error>>Information on errors encountered during the request.
events: Option<Vec<Event>>The list of Events returned by the search.
metadata: Option<Vec<EventMetadata>>Contains the metadata of an event. For more information, see Event.
cursor: Option<String>When a response is truncated, it includes a cursor that you can use in a subsequent request to fetch the next set of events. If empty, this is the final response. For more information, see Pagination.
Implementations
Sourceimpl SearchEventsResponse
impl SearchEventsResponse
Sourcepub fn new() -> SearchEventsResponse
pub fn new() -> SearchEventsResponse
Defines the fields that are included in the response body of a request to the SearchEvents endpoint. Note: if there are errors processing the request, the events field will not be present.