pub struct SubscriptionTestResult {
pub id: Option<String>,
pub status_code: Option<Option<i32>>,
pub payload: Option<Option<String>>,
pub created_at: Option<String>,
pub updated_at: Option<String>,
}Expand description
SubscriptionTestResult : Represents the details of a webhook subscription, including notification URL, event types, and signature key.
Fields
id: Option<String>A Square-generated unique ID for the subscription test result.
status_code: Option<Option<i32>>The status code returned by the subscription notification URL.
payload: Option<Option<String>>An object containing the payload of the test event. For example, a payment.created event.
created_at: Option<String>The timestamp of when the subscription was created, in RFC 3339 format. For example, "2016-09-04T23:59:33.123Z".
updated_at: Option<String>The timestamp of when the subscription was updated, in RFC 3339 format. For example, "2016-09-04T23:59:33.123Z". Because a subscription test result is unique, this field is the same as the created_at field.
Implementations
Sourceimpl SubscriptionTestResult
impl SubscriptionTestResult
Sourcepub fn new() -> SubscriptionTestResult
pub fn new() -> SubscriptionTestResult
Represents the details of a webhook subscription, including notification URL, event types, and signature key.