pub struct SwapPlanRequest {
pub new_plan_variation_id: Option<Option<String>>,
pub phases: Option<Option<Vec<PhaseInput>>>,
}Expand description
SwapPlanRequest : Defines input parameters in a call to the SwapPlan endpoint.
Fields
new_plan_variation_id: Option<Option<String>>The ID of the new subscription plan variation. This field is required.
phases: Option<Option<Vec<PhaseInput>>>A list of PhaseInputs, to pass phase-specific information used in the swap.
Implementations
Sourceimpl SwapPlanRequest
impl SwapPlanRequest
Sourcepub fn new() -> SwapPlanRequest
pub fn new() -> SwapPlanRequest
Defines input parameters in a call to the SwapPlan endpoint.