TerminalAction

Struct TerminalAction 

pub struct TerminalAction {
Show 20 fields pub id: Option<String>, pub device_id: Option<Option<String>>, pub deadline_duration: Option<Option<String>>, pub status: Option<String>, pub cancel_reason: Option<ActionCancelReason>, pub created_at: Option<String>, pub updated_at: Option<String>, pub app_id: Option<String>, pub location_id: Option<String>, pub type: Option<TerminalActionActionType>, pub qr_code_options: Option<Box<QrCodeOptions>>, pub save_card_options: Option<Box<SaveCardOptions>>, pub signature_options: Option<Box<SignatureOptions>>, pub confirmation_options: Option<Box<ConfirmationOptions>>, pub receipt_options: Option<Box<ReceiptOptions>>, pub data_collection_options: Option<Box<DataCollectionOptions>>, pub select_options: Option<Box<SelectOptions>>, pub device_metadata: Option<Box<DeviceMetadata>>, pub await_next_action: Option<Option<bool>>, pub await_next_action_duration: Option<Option<String>>,
}
TerminalAction : Represents an action processed by the Square Terminal.

Fields

id: Option<String>

A unique ID for this TerminalAction.

device_id: Option<Option<String>>

The unique Id of the device intended for this TerminalAction. The Id can be retrieved from /v2/devices api.

deadline_duration: Option<Option<String>>

The duration as an RFC 3339 duration, after which the action will be automatically canceled. TerminalActions that are PENDING will be automatically CANCELED and have a cancellation reason of TIMED_OUT Default: 5 minutes from creation Maximum: 5 minutes

status: Option<String>

The status of the TerminalAction. Options: PENDING, IN_PROGRESS, CANCEL_REQUESTED, CANCELED, COMPLETED

cancel_reason: Option<ActionCancelReason>created_at: Option<String>

The time when the TerminalAction was created as an RFC 3339 timestamp.

updated_at: Option<String>

The time when the TerminalAction was last updated as an RFC 3339 timestamp.

app_id: Option<String>

The ID of the application that created the action.

location_id: Option<String>

The location id the action is attached to, if a link can be made.

type: Option<TerminalActionActionType>qr_code_options: Option<Box<QrCodeOptions>>save_card_options: Option<Box<SaveCardOptions>>signature_options: Option<Box<SignatureOptions>>confirmation_options: Option<Box<ConfirmationOptions>>receipt_options: Option<Box<ReceiptOptions>>data_collection_options: Option<Box<DataCollectionOptions>>select_options: Option<Box<SelectOptions>>device_metadata: Option<Box<DeviceMetadata>>await_next_action: Option<Option<bool>>

Indicates the action will be linked to another action and requires a waiting dialog to be displayed instead of returning to the idle screen on completion of the action. Only supported on SIGNATURE, CONFIRMATION, DATA_COLLECTION, and SELECT types.

await_next_action_duration: Option<Option<String>>

The timeout duration of the waiting dialog as an RFC 3339 duration, after which the waiting dialog will no longer be displayed and the Terminal will return to the idle screen. Default: 5 minutes from when the waiting dialog is displayed Maximum: 5 minutes

Implementations

Source

impl TerminalAction

pub fn new() -> TerminalAction

Represents an action processed by the Square Terminal.