Timecard

Struct Timecard 

pub struct Timecard {
Show 13 fields pub id: Option<String>, pub location_id: String, pub timezone: Option<Option<String>>, pub start_at: String, pub end_at: Option<Option<String>>, pub wage: Option<Box<TimecardWage>>, pub breaks: Option<Option<Vec<Break>>>, pub status: Option<TimecardStatus>, pub version: Option<i32>, pub created_at: Option<String>, pub updated_at: Option<String>, pub team_member_id: String, pub declared_cash_tip_money: Option<Box<Money>>,
}
Timecard : A record of the hourly rate, start time, and end time of a single timecard (shift) for a team member. This might include a record of the start and end times of breaks taken during the shift.

Fields

id: Option<String>

Read only The Square-issued UUID for this object.

location_id: String

The ID of the location for this timecard. The location should be based on where the team member clocked in.

timezone: Option<Option<String>>

Read only The time zone calculated from the location based on the location_id, provided as a convenience value. Format: the IANA time zone database identifier for the location time zone.

start_at: String

The start time of the timecard, in RFC 3339 format and shifted to the location timezone + offset. Precision up to the minute is respected; seconds are truncated.

end_at: Option<Option<String>>

The end time of the timecard, in RFC 3339 format and shifted to the location timezone + offset. Precision up to the minute is respected; seconds are truncated.

wage: Option<Box<TimecardWage>>breaks: Option<Option<Vec<Break>>>

A list of all the paid or unpaid breaks that were taken during this timecard.

status: Option<TimecardStatus>version: Option<i32>

Read only The current version of the timecard, which is incremented with each update. This field is used for optimistic concurrency control to ensure that requests don’t overwrite data from another request.

created_at: Option<String>

The timestamp of when the timecard was created, in RFC 3339 format presented as UTC.

updated_at: Option<String>

The timestamp of when the timecard was last updated, in RFC 3339 format presented as UTC.

team_member_id: String

The ID of the team member this timecard belongs to.

declared_cash_tip_money: Option<Box<Money>>

Implementations

Source

impl Timecard

pub fn new( location_id: String, start_at: String, team_member_id: String, ) -> Timecard

A record of the hourly rate, start time, and end time of a single timecard (shift) for a team member. This might include a record of the start and end times of breaks taken during the shift.