pub struct TimecardWorkday {
pub date_range: Option<Box<DateRange>>,
pub match_timecards_by: Option<TimecardWorkdayMatcher>,
pub default_timezone: Option<Option<String>>,
}Expand description
TimecardWorkday : A Timecard search query filter parameter that sets a range of days that a Timecard must start or end in before passing the filter condition.
Fields
date_range: Option<Box<DateRange>>match_timecards_by: Option<TimecardWorkdayMatcher>default_timezone: Option<Option<String>>Location-specific timezones convert workdays to datetime filters. Every location included in the query must have a timezone or this field must be provided as a fallback. Format: the IANA timezone database identifier for the relevant timezone.
Implementations
Sourceimpl TimecardWorkday
impl TimecardWorkday
Sourcepub fn new() -> TimecardWorkday
pub fn new() -> TimecardWorkday
A Timecard search query filter parameter that sets a range of days that a Timecard must start or end in before passing the filter condition.