pub enum TransactionProduct {
Register,
ExternalApi,
Billing,
Appointments,
Invoices,
OnlineStore,
Payroll,
Other,
}Expand description
TransactionProduct : Indicates the Square product used to process a transaction. Indicates the Square product used to process a transaction.
Variants