pub struct UpdateCustomerGroupRequest {
pub group: Box<CustomerGroup>,
}Expand description
UpdateCustomerGroupRequest : Defines the body parameters that can be included in a request to the UpdateCustomerGroup endpoint.
Fields
group: Box<CustomerGroup>Implementations
Sourceimpl UpdateCustomerGroupRequest
impl UpdateCustomerGroupRequest
Sourcepub fn new(group: CustomerGroup) -> UpdateCustomerGroupRequest
pub fn new(group: CustomerGroup) -> UpdateCustomerGroupRequest
Defines the body parameters that can be included in a request to the UpdateCustomerGroup endpoint.