pub struct UpdateCustomerResponse {
pub errors: Option<Vec<Error>>,
pub customer: Option<Box<Customer>>,
}Expand description
UpdateCustomerResponse : Defines the fields that are included in the response body of a request to the UpdateCustomer or BulkUpdateCustomers endpoint. Either errors or customer is present in a given response (never both).
Fields
errors: Option<Vec<Error>>Any errors that occurred during the request.
customer: Option<Box<Customer>>Implementations
Sourceimpl UpdateCustomerResponse
impl UpdateCustomerResponse
Sourcepub fn new() -> UpdateCustomerResponse
pub fn new() -> UpdateCustomerResponse
Defines the fields that are included in the response body of a request to the UpdateCustomer or BulkUpdateCustomers endpoint. Either errors or customer is present in a given response (never both).