pub struct UpdateOrderCustomAttributeDefinitionResponse {
pub custom_attribute_definition: Option<Box<CustomAttributeDefinition>>,
pub errors: Option<Vec<Error>>,
}Expand description
UpdateOrderCustomAttributeDefinitionResponse : Represents a response from updating an order custom attribute definition.
Fields
custom_attribute_definition: Option<Box<CustomAttributeDefinition>>errors: Option<Vec<Error>>Any errors that occurred during the request.
Implementations
Sourceimpl UpdateOrderCustomAttributeDefinitionResponse
impl UpdateOrderCustomAttributeDefinitionResponse
Sourcepub fn new() -> UpdateOrderCustomAttributeDefinitionResponse
pub fn new() -> UpdateOrderCustomAttributeDefinitionResponse
Represents a response from updating an order custom attribute definition.