pub struct UpdateTeamMemberResponse {
pub team_member: Option<Box<TeamMember>>,
pub errors: Option<Vec<Error>>,
}Expand description
UpdateTeamMemberResponse : Represents a response from an update request containing the updated TeamMember object or error messages.
Fields
team_member: Option<Box<TeamMember>>errors: Option<Vec<Error>>The errors that occurred during the request.
Implementations
Sourceimpl UpdateTeamMemberResponse
impl UpdateTeamMemberResponse
Sourcepub fn new() -> UpdateTeamMemberResponse
pub fn new() -> UpdateTeamMemberResponse
Represents a response from an update request containing the updated TeamMember object or error messages.