pub struct UpsertOrderCustomAttributeRequest {
pub custom_attribute: Box<CustomAttribute>,
pub idempotency_key: Option<Option<String>>,
}Expand description
UpsertOrderCustomAttributeRequest : Represents an upsert request for an order custom attribute.
Fields
custom_attribute: Box<CustomAttribute>idempotency_key: Option<Option<String>>A unique identifier for this request, used to ensure idempotency. For more information, see Idempotency.
Implementations
Sourceimpl UpsertOrderCustomAttributeRequest
impl UpsertOrderCustomAttributeRequest
Sourcepub fn new(
custom_attribute: CustomAttribute,
) -> UpsertOrderCustomAttributeRequest
pub fn new( custom_attribute: CustomAttribute, ) -> UpsertOrderCustomAttributeRequest
Represents an upsert request for an order custom attribute.