pub struct Vendor {
pub id: Option<String>,
pub created_at: Option<String>,
pub updated_at: Option<String>,
pub name: Option<Option<String>>,
pub address: Option<Box<Address>>,
pub contacts: Option<Option<Vec<VendorContact>>>,
pub account_number: Option<Option<String>>,
pub note: Option<Option<String>>,
pub version: Option<i32>,
pub status: Option<VendorStatus>,
}Expand description
Vendor : Represents a supplier to a seller.
Fields
id: Option<String>A unique Square-generated ID for the Vendor. This field is required when attempting to update a Vendor.
created_at: Option<String>An RFC 3339-formatted timestamp that indicates when the Vendor was created.
updated_at: Option<String>An RFC 3339-formatted timestamp that indicates when the Vendor was last updated.
name: Option<Option<String>>address: Option<Box<Address>>contacts: Option<Option<Vec<VendorContact>>>The contacts of the Vendor.
account_number: Option<Option<String>>The account number of the Vendor.
note: Option<Option<String>>A note detailing information about the Vendor.
version: Option<i32>The version of the Vendor.
status: Option<VendorStatus>Implementations