pub enum VendorUpdatedEventObjectOperation {
Updated,
}Expand description
VendorUpdatedEventObjectOperation : The operation that can be performed against a vendor to cause the event to be published. The operation that can be performed against a vendor to cause the event to be published.
Variants
Updated