WageSetting

Struct WageSetting 

pub struct WageSetting {
    pub team_member_id: Option<Option<String>>,
    pub job_assignments: Option<Option<Vec<JobAssignment>>>,
    pub is_overtime_exempt: Option<Option<bool>>,
    pub version: Option<i32>,
    pub created_at: Option<String>,
    pub updated_at: Option<String>,
}
WageSetting : Represents information about the overtime exemption status, job assignments, and compensation for a team member.

Fields

team_member_id: Option<Option<String>>

The ID of the team member associated with the wage setting.

job_assignments: Option<Option<Vec<JobAssignment>>>

Required The ordered list of jobs that the team member is assigned to. The first job assignment is considered the team member’s primary job.

is_overtime_exempt: Option<Option<bool>>

Whether the team member is exempt from the overtime rules of the seller’s country.

version: Option<i32>

Read only Used for resolving concurrency issues. The request fails if the version provided does not match the server version at the time of the request. If not provided, Square executes a blind write, potentially overwriting data from another write. For more information, see optimistic concurrency.

created_at: Option<String>

The timestamp when the wage setting was created, in RFC 3339 format.

updated_at: Option<String>

The timestamp when the wage setting was last updated, in RFC 3339 format.

Implementations

Source

impl WageSetting

pub fn new() -> WageSetting

Represents information about the overtime exemption status, job assignments, and compensation for a team member.