pub async fn create_checkout(
configuration: &Configuration,
location_id: &str,
create_checkout_request: CreateCheckoutRequest,
) -> Result<CreateCheckoutResponse, Error<CreateCheckoutError>>Expand description
Links a checkoutId to a checkout_page_url that customers are directed to in order to provide their payment information using a payment processing workflow hosted on connect.squareup.com. NOTE: The Checkout API has been updated with new features. For more information, see Checkout API highlights.