pub async fn batch_retrieve_inventory_changes(
configuration: &Configuration,
batch_retrieve_inventory_changes_request: BatchRetrieveInventoryChangesRequest,
) -> Result<BatchRetrieveInventoryChangesResponse, Error<BatchRetrieveInventoryChangesError>>Expand description
Returns historical physical counts and adjustments based on the provided filter criteria. Results are paginated and sorted in ascending order according their occurred_at timestamp (oldest first). BatchRetrieveInventoryChanges is a catch-all query endpoint for queries that cannot be handled by other, simpler endpoints.