pub async fn update_shift(
configuration: &Configuration,
id: &str,
update_shift_request: UpdateShiftRequest,
) -> Result<UpdateShiftResponse, Error<UpdateShiftError>>Expand description
Updates an existing Shift. When adding a Break to a Shift, any earlier Break instances in the Shift have the end_at property set to a valid RFC-3339 datetime string. When closing a Shift, all Break instances in the Shift must be complete with end_at set on each Break.