Creates a new order, in the DRAFT state, by duplicating an existing order. The newly created order has only the core fields (such as line items, taxes, and discounts) copied from the original order.
Creates a new order that can include information about products for purchase and settings to apply to the purchase. To pay for a created order, see Pay for Orders. You can modify open orders using the UpdateOrder endpoint.
Pay for an order using one or more approved payments or settle an order with a total of 0. The total of the payment_ids listed in the request must be equal to the order total. Orders with a total amount of 0 can be marked as paid by specifying an empty array of payment_ids in the request. To be used with PayOrder, a payment must: - Reference the order by specifying the order_id when creating the payment. Any approved payments that reference the same order_id not specified in the payment_ids is canceled. - Be approved with delayed capture. Using a delayed capture payment with PayOrder completes the approved payment.
Search all orders for one or more locations. Orders include all sales, returns, and exchanges regardless of how or when they entered the Square ecosystem (such as Point of Sale, Invoices, and Connect APIs). SearchOrders requests need to specify which locations to search and define a SearchOrdersQuery object that controls how to sort or filter the results. Your SearchOrdersQuery can: Set filter criteria. Set the sort order. Determine whether to return results as complete Order objects or as OrderEntry objects. Note that details for orders processed with Square Point of Sale while in offline mode might not be transmitted to Square for up to 72 hours. Offline orders have a created_at value that reflects the time the order was created, not the time it was subsequently transmitted to Square.
Updates an open order by adding, replacing, or deleting fields. Orders with a COMPLETED or CANCELED state cannot be updated. An UpdateOrder request requires the following: - The order_id in the endpoint path, identifying the order to update. - The latest version of the order to update. - The sparse order containing only the fields to update and the version to which the update is being applied. - If deleting fields, the dot notation paths identifying the fields to clear. To pay for an order, see Pay for Orders.