pub struct CatalogSubscriptionPlanVariation {
pub name: String,
pub phases: Vec<SubscriptionPhase>,
pub subscription_plan_id: Option<Option<String>>,
pub monthly_billing_anchor_date: Option<Option<i64>>,
pub can_prorate: Option<Option<bool>>,
pub successor_plan_variation_id: Option<Option<String>>,
}Expand description
CatalogSubscriptionPlanVariation : Describes a subscription plan variation. A subscription plan variation represents how the subscription for a product or service is sold. For more information, see Subscription Plans and Variations.
Fields
name: StringThe name of the plan variation.
phases: Vec<SubscriptionPhase>A list containing each SubscriptionPhase for this plan variation.
subscription_plan_id: Option<Option<String>>The id of the subscription plan, if there is one.
monthly_billing_anchor_date: Option<Option<i64>>The day of the month the billing period starts.
can_prorate: Option<Option<bool>>Whether bills for this plan variation can be split for proration.
successor_plan_variation_id: Option<Option<String>>The ID of a "successor" plan variation to this one. If the field is set, and this object is disabled at all locations, it indicates that this variation is deprecated and the object identified by the successor ID be used in its stead.
Implementations
Sourceimpl CatalogSubscriptionPlanVariation
impl CatalogSubscriptionPlanVariation
Sourcepub fn new(
name: String,
phases: Vec<SubscriptionPhase>,
) -> CatalogSubscriptionPlanVariation
pub fn new( name: String, phases: Vec<SubscriptionPhase>, ) -> CatalogSubscriptionPlanVariation
Describes a subscription plan variation. A subscription plan variation represents how the subscription for a product or service is sold. For more information, see Subscription Plans and Variations.