pub struct InvoiceRecipient {
pub customer_id: Option<Option<String>>,
pub given_name: Option<String>,
pub family_name: Option<String>,
pub email_address: Option<String>,
pub address: Option<Box<Address>>,
pub phone_number: Option<String>,
pub company_name: Option<String>,
pub tax_ids: Option<Box<InvoiceRecipientTaxIds>>,
}Expand description
InvoiceRecipient : Represents a snapshot of customer data. This object stores customer data that is displayed on the invoice and that Square uses to deliver the invoice. When you provide a customer ID for a draft invoice, Square retrieves the associated customer profile and populates the remaining InvoiceRecipient fields. You cannot update these fields after the invoice is published. Square updates the customer ID in response to a merge operation, but does not update other fields.
Fields
customer_id: Option<Option<String>>The ID of the customer. This is the customer profile ID that you provide when creating a draft invoice.
given_name: Option<String>The recipient’s given (that is, first) name.
family_name: Option<String>The recipient’s family (that is, last) name.
email_address: Option<String>The recipient’s email address.
address: Option<Box<Address>>phone_number: Option<String>The recipient’s phone number.
company_name: Option<String>The name of the recipient’s company.
tax_ids: Option<Box<InvoiceRecipientTaxIds>>Implementations
Sourceimpl InvoiceRecipient
impl InvoiceRecipient
Sourcepub fn new() -> InvoiceRecipient
pub fn new() -> InvoiceRecipient
Represents a snapshot of customer data. This object stores customer data that is displayed on the invoice and that Square uses to deliver the invoice. When you provide a customer ID for a draft invoice, Square retrieves the associated customer profile and populates the remaining InvoiceRecipient fields. You cannot update these fields after the invoice is published. Square updates the customer ID in response to a merge operation, but does not update other fields.