pub struct OrderServiceCharge {Show 16 fields
pub uid: Option<Option<String>>,
pub name: Option<Option<String>>,
pub catalog_object_id: Option<Option<String>>,
pub catalog_version: Option<Option<i64>>,
pub percentage: Option<Option<String>>,
pub amount_money: Option<Box<Money>>,
pub applied_money: Option<Box<Money>>,
pub total_money: Option<Box<Money>>,
pub total_tax_money: Option<Box<Money>>,
pub calculation_phase: Option<OrderServiceChargeCalculationPhase>,
pub taxable: Option<Option<bool>>,
pub applied_taxes: Option<Option<Vec<OrderLineItemAppliedTax>>>,
pub metadata: Option<Option<HashMap<String, String>>>,
pub type: Option<OrderServiceChargeType>,
pub treatment_type: Option<OrderServiceChargeTreatmentType>,
pub scope: Option<OrderServiceChargeScope>,
}Expand description
OrderServiceCharge : Represents a service charge applied to an order.
Fields
uid: Option<Option<String>>A unique ID that identifies the service charge only within this order.
name: Option<Option<String>>The name of the service charge. This is unused and null for AUTO_GRATUITY to match the behavior on Bills.
catalog_object_id: Option<Option<String>>The catalog object ID referencing the service charge CatalogObject.
catalog_version: Option<Option<i64>>The version of the catalog object that this service charge references.
percentage: Option<Option<String>>The service charge percentage as a string representation of a decimal number. For example, \"7.25\" indicates a service charge of 7.25%. Exactly 1 of percentage or amount_money should be set.
amount_money: Option<Box<Money>>applied_money: Option<Box<Money>>total_money: Option<Box<Money>>total_tax_money: Option<Box<Money>>calculation_phase: Option<OrderServiceChargeCalculationPhase>taxable: Option<Option<bool>>Indicates whether the service charge can be taxed. If set to true, order-level taxes automatically apply to the service charge. Note that service charges calculated in the TOTAL_PHASE cannot be marked as taxable.
applied_taxes: Option<Option<Vec<OrderLineItemAppliedTax>>>The list of references to the taxes applied to this service charge. Each OrderLineItemAppliedTax has a tax_uid that references the uid of a top-level OrderLineItemTax that is being applied to this service charge. On reads, the amount applied is populated. An OrderLineItemAppliedTax is automatically created on every taxable service charge for all ORDER scoped taxes that are added to the order. OrderLineItemAppliedTax records for LINE_ITEM scoped taxes must be added in requests for the tax to apply to any taxable service charge. Taxable service charges have the taxable field set to true and calculated in the SUBTOTAL_PHASE. To change the amount of a tax, modify the referenced top-level tax.
metadata: Option<Option<HashMap<String, String>>>Application-defined data attached to this service charge. Metadata fields are intended to store descriptive references or associations with an entity in another system or store brief information about the object. Square does not process this field; it only stores and returns it in relevant API calls. Do not use metadata to store any sensitive information (such as personally identifiable information or card details). Keys written by applications must be 60 characters or less and must be in the character set [a-zA-Z0-9_-]. Entries can also include metadata generated by Square. These keys are prefixed with a namespace, separated from the key with a ‘:’ character. Values have a maximum length of 255 characters. An application can have up to 10 entries per metadata field. Entries written by applications are private and can only be read or modified by the same application. For more information, see Metadata.
type: Option<OrderServiceChargeType>treatment_type: Option<OrderServiceChargeTreatmentType>scope: Option<OrderServiceChargeScope>Implementations
Sourceimpl OrderServiceCharge
impl OrderServiceCharge
Sourcepub fn new() -> OrderServiceCharge
pub fn new() -> OrderServiceCharge
Represents a service charge applied to an order.