pub struct PaymentRefund {Show 17 fields
pub id: String,
pub status: Option<Option<String>>,
pub location_id: Option<Option<String>>,
pub unlinked: Option<bool>,
pub destination_type: Option<Option<String>>,
pub destination_details: Option<Box<DestinationDetails>>,
pub amount_money: Box<Money>,
pub app_fee_money: Option<Box<Money>>,
pub app_fee_allocations: Option<Vec<Value>>,
pub processing_fee: Option<Option<Vec<ProcessingFee>>>,
pub payment_id: Option<Option<String>>,
pub order_id: Option<Option<String>>,
pub reason: Option<Option<String>>,
pub created_at: Option<String>,
pub updated_at: Option<String>,
pub team_member_id: Option<String>,
pub terminal_refund_id: Option<String>,
}Expand description
PaymentRefund : Represents a refund of a payment made using Square. Contains information about the original payment and the amount of money refunded.
Fields
id: StringThe unique ID for this refund, generated by Square.
status: Option<Option<String>>The refund’s status: - PENDING - Awaiting approval. - COMPLETED - Successfully completed. - REJECTED - The refund was rejected. - FAILED - An error occurred.
location_id: Option<Option<String>>The location ID associated with the payment this refund is attached to.
unlinked: Option<bool>Flag indicating whether or not the refund is linked to an existing payment in Square.
destination_type: Option<Option<String>>The destination type for this refund. Current values include CARD, BANK_ACCOUNT, WALLET, BUY_NOW_PAY_LATER, CASH, EXTERNAL, and SQUARE_ACCOUNT.
destination_details: Option<Box<DestinationDetails>>amount_money: Box<Money>app_fee_money: Option<Box<Money>>app_fee_allocations: Option<Vec<Value>>Details pertaining to contributors to the refund of the application fee.
processing_fee: Option<Option<Vec<ProcessingFee>>>Processing fees and fee adjustments assessed by Square for this refund.
payment_id: Option<Option<String>>The ID of the payment associated with this refund.
order_id: Option<Option<String>>The ID of the order associated with the refund.
reason: Option<Option<String>>The reason for the refund.
created_at: Option<String>The timestamp of when the refund was created, in RFC 3339 format.
updated_at: Option<String>The timestamp of when the refund was last updated, in RFC 3339 format.
team_member_id: Option<String>An optional ID of the team member associated with taking the payment.
terminal_refund_id: Option<String>An optional ID for a Terminal refund.
Implementations
Sourceimpl PaymentRefund
impl PaymentRefund
Sourcepub fn new(id: String, amount_money: Money) -> PaymentRefund
pub fn new(id: String, amount_money: Money) -> PaymentRefund
Represents a refund of a payment made using Square. Contains information about the original payment and the amount of money refunded.